@@ -7,7 +7,7 @@ import socket
 from asyncio.log import logger
 from dataclasses import dataclass, field
 from importlib import metadata
-from typing import Any, TypedDict
+from typing import Any, TypedDict, cast
 
 import async_timeout
 import backoff
@@ -70,7 +70,7 @@ class BSBLAN:
         base_path: str = "/JQ",
         data: dict[str, object] | None = None,
         params: dict[str, object] | None = None,
-    ) -> Any:
+    ) -> dict[str, Any]:
         """Handle a request to a BSBLAN device.
 
         A generic method for sending/handling HTTP requests done against
@@ -86,7 +86,7 @@ class BSBLAN:
 
         Returns:
         -------
-            A Python dictionary (Json decoded) with the response from
+            A Python dictionary (JSON decoded) with the response from
             the BSBLAN API.
 
         Raises:
@@ -149,7 +149,7 @@ class BSBLAN:
             text = await response.text()
             raise BSBLANError(BSBLANError.message + f" ({text})")
 
-        return await response.json()
+        return cast(dict[str, Any], await response.json())
 
     async def state(self) -> State:
         """Get the current state from BSBLAN device.
@@ -172,7 +172,7 @@ class BSBLAN:
 
         # set hvac_mode with correct value
         data["hvac_mode"]["value"] = HVAC_MODE_DICT[int(data["hvac_mode"]["value"])]
-        return State.model_validate(data)
+        return State.parse_obj(data)
 
     async def sensor(self) -> Sensor:
         """Get the sensor information from BSBLAN device.
@@ -190,7 +190,7 @@ class BSBLAN:
         # retrieve sensor params so we can build the data structure
         data = await self._request(params={"Parameter": f"{self._sensor_list}"})
         data = dict(zip(self._sensor_params, list(data.values()), strict=True))
-        return Sensor.model_validate(data)
+        return Sensor.parse_obj(data)
 
     async def static_values(self) -> StaticState:
         """Get the static information from BSBLAN device.
@@ -210,7 +210,7 @@ class BSBLAN:
         data = dict(zip(self._static_params, list(data.values()), strict=True))
         self._min_temp = data["min_temp"]["value"]
         self._max_temp = data["max_temp"]["value"]
-        return StaticState.model_validate(data)
+        return StaticState.parse_obj(data)
 
     async def _get_dict_version(self) -> dict[Any, Any]:
         """Get the version from device.
@@ -249,7 +249,7 @@ class BSBLAN:
 
         """
         device_info = await self._request(base_path="/JI")
-        return Device.model_validate(device_info)
+        return Device.parse_obj(device_info)
 
     async def info(self) -> Info:
         """Get information about the current heating system config.
@@ -266,7 +266,7 @@ class BSBLAN:
 
         data = await self._request(params={"Parameter": f"{self._info}"})
         data = dict(zip(self._device_params, list(data.values()), strict=True))
-        return Info.model_validate(data)
+        return Info.parse_obj(data)
 
     async def _get_parameters(self, params: dict[Any, Any]) -> dict[Any, Any]:
         """Get the parameters info from BSBLAN device.
